.array-rows {
    .row {
        display: flex;
        margin: 0;

        input[type='text'] {
            height: auto;
        }

        + .row {
            margin-top: 1rem;
        }
    }

    button.context {
        margin-top: 1rem;
        font-size: 1.25rem;
    }
}
