.reference-field-wrapper {
    .references {
        margin-bottom: 1rem;

        .reference {
            button {
                margin-right: 0.5rem;
            }
        }
    }
}

.modal-content-wrapper {
    .modal-breadcrumbs {
        margin: 0.5rem 0;
    }

    .content-results-wrapper {
        max-height: calc(95vh - 300px);
        overflow: scroll;
        margin: 2rem 0;

        .content-item {
            margin: 0.5rem 0;
            display: flex;
            align-items: center;

            span.content-title {
                margin-right: auto;
                margin-left: 0.5rem;

                &.selected-item {
                    opacity: 0.6;
                }
            }

            button {
                font-size: 1.5rem;
            }
        }
    }
}
