.array-rows .row{display:-webkit-box;display:-ms-flexbox;display:flex;margin:0}.array-rows .row input[type=text]{height:auto}.array-rows .row+.row{margin-top:1rem}.array-rows button.context{margin-top:1rem;font-size:1.25rem}
.reference-field-wrapper .references{margin-bottom:1rem}.reference-field-wrapper .references .reference button{margin-right:.5rem}.modal-content-wrapper .modal-breadcrumbs{margin:.5rem 0}.modal-content-wrapper .content-results-wrapper{max-height:calc(95vh - 300px);overflow:scroll;margin:2rem 0}.modal-content-wrapper .content-results-wrapper .content-item{margin:.5rem 0;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.modal-content-wrapper .content-results-wrapper .content-item span.content-title{margin-right:auto;margin-left:.5rem}.modal-content-wrapper .content-results-wrapper .content-item span.content-title.selected-item{opacity:.6}.modal-content-wrapper .content-results-wrapper .content-item button{font-size:1.5rem}
.json-textarea-widget{background-color:#ccc}.json-textarea-widget .data-wrapper .json-row{padding:10px;margin:10px;background-color:#fff}.json-textarea-widget .data-wrapper .json-row .row-header{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin-bottom:2rem}.json-textarea-widget .data-wrapper .json-row .row-header button.standalone{font-size:1.5rem}.json-textarea-widget .data-wrapper .json-row .row-header button.standalone+button.standalone{margin-left:.5rem}.json-textarea-widget .data-wrapper .json-row .row-header button.standalone+strong{margin-left:1.5rem}.json-textarea-widget .data-wrapper .json-row .row-header button.disruptive{font-size:1.5rem}.json-textarea-widget .data-wrapper .json-row .row-header strong{margin-right:auto}.json-textarea-widget .data-wrapper .json-row>.column{margin-bottom:3rem}.json-textarea-widget .data-wrapper .data-footer{padding:10px}.json-textarea-widget .data-wrapper .data-footer button.context{font-size:1.5rem}

/*# sourceMappingURL=main.css.map*/